/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {fetch} from 'frontend-js-web';

import {HEADERS, HEADLESS_BATCH_ENGINE_URL} from './constants';

export function getExportTaskStatusURL(externalReferenceCode) {
	return `${HEADLESS_BATCH_ENGINE_URL}/export-task/by-external-reference-code/${externalReferenceCode}`;
}

export function getExportFileURL(externalReferenceCode) {
	return `${HEADLESS_BATCH_ENGINE_URL}/export-task/by-external-reference-code/${externalReferenceCode}/content`;
}

export async function exportStatus(externalReferenceCode) {
	const response = await fetch(
		getExportTaskStatusURL(externalReferenceCode),
		{
			headers: HEADERS,
		}
	);

	if (!response.ok) {
		throw new Error(response);
	}

	return await response.json();
}

export async function fetchExportedFile(externalReferenceCode) {
	const response = await fetch(getExportFileURL(externalReferenceCode));
	const blob = await response.blob();

	return URL.createObjectURL(blob);
}
